summaryrefslogtreecommitdiff
path: root/src/vector.h
diff options
context:
space:
mode:
authorRobert James Kaes <rjkaes@users.sourceforge.net>2003-05-29 20:47:52 +0000
committerRobert James Kaes <rjkaes@users.sourceforge.net>2003-05-29 20:47:52 +0000
commit42f9f37afcc97fae11d76bac07cc2dbcd37c4b6c (patch)
tree929fe8a45957932f2aa143ace66acbc1c88d620f /src/vector.h
parent4a377a712d5a17d1cd2c5e46f8c0873824a2448f (diff)
downloadtinyproxy-42f9f37afcc97fae11d76bac07cc2dbcd37c4b6c.tar.gz
tinyproxy-42f9f37afcc97fae11d76bac07cc2dbcd37c4b6c.zip
(vector_append): Renamed the vector_insert() function to more
accurately indicate that entries are appended to the end of the vector.
Diffstat (limited to '')
-rw-r--r--src/vector.h12
1 files changed, 6 insertions, 6 deletions
diff --git a/src/vector.h b/src/vector.h
index dadc421..8b938f1 100644
--- a/src/vector.h
+++ b/src/vector.h
@@ -1,4 +1,4 @@
-/* $Id: vector.h,v 1.1 2002-04-07 21:29:23 rjkaes Exp $
+/* $Id: vector.h,v 1.2 2003-05-29 20:47:51 rjkaes Exp $
*
* A vector implementation. The vector can be of an arbritrary length, and
* the data for each entry is an lump of data (the size is stored in the
@@ -44,15 +44,15 @@ extern vector_t vector_create(void);
extern int vector_delete(vector_t vector);
/*
* When you insert a piece of data into the vector, the data will be
* duplicated, so you must free your copy if it was created on the
* heap. The data must be non-NULL and the length must be greater
* than zero.
*
* Returns: negative on error
* 0 upon successful insert.
*/
-extern int vector_insert(vector_t vector, void *data, ssize_t len);
+extern int vector_append(vector_t vector, void *data, ssize_t len);
/*
* A pointer to the data at position "pos" (zero based) is returned in the
@@ -44,15 +44,15 @@ extern vector_t vector_create(void);
extern int vector_delete(vector_t vector);
/*
- * When you insert a piece of data into the vector, the data will be
- * duplicated, so you must free your copy if it was created on the
- * heap. The data must be non-NULL and the length must be greater
- * than zero.
+ * Append an entry to the end of the vector. When you insert a piece of
+ * data into the vector, the data will be duplicated, so you must free your
+ * copy if it was created on the heap. The data must be non-NULL and the
+ * length must be greater than zero.
*
* Returns: negative on error